summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger/variablewidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/debugger/variablewidget.h')
-rw-r--r--languages/cpp/debugger/variablewidget.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/languages/cpp/debugger/variablewidget.h b/languages/cpp/debugger/variablewidget.h
index da885216..cb8ffb0f 100644
--- a/languages/cpp/debugger/variablewidget.h
+++ b/languages/cpp/debugger/variablewidget.h
@@ -186,16 +186,16 @@ private:
/***************************************************************************/
/***************************************************************************/
-/** List view item that can 'trim' outdated children.
+/** List view item that can 'trim' outdated tqchildren.
- The instances of this class hold a number of children corresponding
+ The instances of this class hold a number of tqchildren corresponding
to variables. When program state changes, such as after a step in source,
some variable values can change, and some variables can go out of scope.
We need
- highlight modified variables
- remove gone variables
- We could just remove all children and repopulate the list from
+ We could just remove all tqchildren and repopulate the list from
the data from debugger, but then we'd loose information about previous
variable values.
@@ -286,7 +286,7 @@ public:
/** Recursively clears the varobjName_ field, making
*this completely disconnected from gdb.
- Automatically makes *this and children disables,
+ Automatically makes *this and tqchildren disables,
since there's no possible interaction with unhooked
object.
*/
@@ -300,7 +300,7 @@ public:
format_t formatFromGdbModifier(char c) const;
/** Clears highliting for this variable and
- all its children. */
+ all its tqchildren. */
void clearHighlight();
/** Sets new top-level textual value of this variable.
@@ -333,7 +333,7 @@ private:
- sets varobjName_ to 'name'
- sets format, if it's not default one
- gets initial value
- - if item is open, gets children.
+ - if item is open, gets tqchildren.
*/
void setVarobjName(const TQString& name);
@@ -348,12 +348,12 @@ private:
int column, int width, int align );
void varobjCreated(const GDBMI::ResultRecord& r);
void valueDone(const GDBMI::ResultRecord& r);
- void childrenDone(const GDBMI::ResultRecord& r);
- void childrenOfFakesDone(const GDBMI::ResultRecord& r);
+ void tqchildrenDone(const GDBMI::ResultRecord& r);
+ void tqchildrenOfFakesDone(const GDBMI::ResultRecord& r);
void handleCurrentAddress(const TQValueVector<TQString>& lines);
void handleType(const TQValueVector<TQString>& lines);
- void createChildren(const GDBMI::ResultRecord& r, bool children_of_fake);
+ void createChildren(const GDBMI::ResultRecord& r, bool tqchildren_of_fake);
/** Called to handle the output of the cli print command.
*/
@@ -391,7 +391,7 @@ private:
static int varobjIndex;
int numChildren_;
- bool childrenFetched_;
+ bool tqchildrenFetched_;
TQString currentAddress_;
TQString lastObtainedAddress_;